## S3 method for class 'coxph':
rsq(x, ..., sigD = 2)
## S3 method for class 'survfit':
rsq(x, ..., sigD = 2)
Arguments
x
A survfit or coxph object
sigD
significant digits (for ease of display).
If sigD=NULL, will return the original numbers.
...
Additional arguments (not implemented).
Value
A list with the following elements:
codThe coefficient of determination, which is
$$R^2=1-\exp(\frac{2}{n}L_0-L_1)$$
where $L_0$ and $L_1$ are the log partial
likelihoods for the null and full models respectively
and $n$
is the number of observations in the data set.
merThe measure of explained randomness, which is:
$$R^2_{mer}=1-\exp(\frac{2}{m}L_0-L_1)$$
where $m$ is the number of observed events.
mevThe measure of explained variation (similar to
that for linear regression), which is:
$$R^2=\frac{R^2_{mer}}{R^2_{mer} + \frac{\pi}{6}(1-R^2_{mer})}$$
References
Nagelkerke NJD, 1991.
A Note on a General Definition of the Coefficient of Determination.
Biometrika78(3):691--92.
http://www.jstor.org/stable/2337038{JSTOR}
O'Quigley J, Xu R, Stare J, 2005.
Explained randomness in proportional hazards models.
Stat Med24(3):479--89.
http://dx.doi.org/10.1002/sim.1946{Wiley (paywall)}
http://www.math.ucsd.edu/~rxu/igain2.pdf{Available at UCSD}
Royston P, 2006.
Explained variation for survival models.
The Stata Journal6(1):83--96.
http://www.stata-journal.com/sjpdf.html?articlenum=st0098{The Stata Journal}