| Package: |
| survMisc |
| Type: |
| Package |
| Version: |
| 0.5 |
| Date: |
| 2015-07-15 |
| License: |
| GPL (>= 2) |
package:survival.The intent is to generate a workspace for some of the common tasks arising in survival analysis. There are references in many of the functions to the textbooks:
| K&M |
| Klein J, Moeschberger M (2003). Survival Analysis, 2nd edition. |
| New York: Springer. Springer (paywall). |
| T&G |
| Therneau TM, Grambsch PM (2000). Modeling Survival Data: Extending the Cox Model. |
Notes for developers
a1 <- 1.
For bug reports, feature requests or suggestions for improvement, please try to submit to github. Otherwise email me at the address below.