A data.frame with $90$ rows (observations) and $3$ columns (variables).
source
Klein J, Moeschberger. Survival Analysis, 2nd edition. Springer 2003.
Example 7.9, pg 224.
Details
Data from a trial of locally unresectable gastic cancer.
Patients ($n=45$ in each group) were randomized to one of two groups:
chemotheapy vs. chemotherapy + radiotherapy.
Columns are:
[object Object],[object Object],[object Object]
References
Gastrointestinal Tumor Study Group, 1982.
A comparison of combination chemotherapy and
combined modality therapy for locally advanced gastric carcinoma.
Cancer. 49(9):1771-7.
http://dx.doi.org/10.1002/1097-0142(19820501)49:9<1771::aid-cncr2820490907>3.0.CO;2-M1771::aid-cncr2820490907>{
Wiley (free)}.
Stablein DM, Koutrouvelis IA, 1985.
A two-sample test sensitive to crossing hazards in uncensored and singly censored data.
Biometrics. 41(3):643-52.
http://www.jstor.org/stable/2531284{JSTOR}.