survMisc_package: Miscellaneous Functions for Survival Analysis
Description
ll{
Package: survMisc
Type: Package
Version: 0.5
Date: 2015-07-15
License: GPL (>= 2)
LazyLoad: yes
}
A collection of functions for the analysis of survival data. These
extend the methods already available in package:survival.
The intent is to generate a workspace for some of the common tasks
arising in survival analysis.
There are references in many of the functions to the textbooks:
cl{
K&M Klein J, Moeschberger M (2003).
Survival Analysis, 2nd edition.
New York: Springer.
http://dx.doi.org/10.1007/b97377{Springer (paywall)}.
T&G Therneau TM, Grambsch PM (2000).
Modeling Survival Data: Extending the Cox Model.
New York: Springer.
http://dx.doi.org/10.1007/978-1-4757-3294-8{Springer (paywall)}.
}Notes for developers{
- This package should be regarded as 'in development' until
release 1.0, meaning that there may be changes to certain function
names and parameters, although I will try to keep this to a minimum.
As such it is recommended that other packages donotdepend on or import from this
one until at least version 1.0.
- Naming tends to follow thecamelCaseconvention;
variables within functions are typically alphanumeric e.g.
a1 <- 1.
}
For bug reports, feature requests or suggestions for improvement,
please try to submit to https://github.com/dardisco/survMisc/issues{github}.
Otherwise email me at the address below.